@@ -1,6 +1,8 @@
 import numpy
 import scipy.constants as codata
 
+from shadow4.beam.beam import Beam
+
 from shadow4.sources.source_geometrical.probability_distributions import Rectangle2D, Ellipse2D, Gaussian2D
 from shadow4.sources.source_geometrical.probability_distributions import Flat2D, Uniform2D, Conical2D
 
@@ -265,6 +267,10 @@ class SourceGeometrical(object):
         rays[:,11] = numpy.arange(N) + 1          # index
         return rays
 
+    def calculate_beam(self,N=5000,POL_DEG=1.0,POL_ANGLE=0.0,F_COHER=False):
+        rays = self.calculate_rays(N=N, POL_DEG=POL_DEG, POL_ANGLE=POL_ANGLE, F_COHER=F_COHER)
+        return Beam.initialize_from_array(rays)
+
     def calculate_rays(self,N=5000,POL_DEG=1.0,POL_ANGLE=0.0,F_COHER=False):
 
         rays = self._sample_rays_default(N)
@@ -450,9 +456,9 @@ class SourceGeometrical(object):
         for i in range(3):
             AP_VEC[:, i] *= AZ
 
+
         rays[:, 6:9] = A_VEC
         rays[:, 15:18] = AP_VEC
-
         #
         # ! C
         # ! C Now the phases of A_VEC and AP_VEC.
@@ -497,79 +503,5 @@ class SourceGeometrical(object):
         return u / u_norm
 
 if __name__ == "__main__":
-
-    from srxraylib.plot.gol import plot,plot_scatter, set_qt
-    set_qt()
-
-    # rectangle
-    gs = SourceGeometrical()
-    gs.set_spatial_type_rectangle(4,2)
-    rays = gs.calculate_rays(1000)
-
-    for i in range(6):
-        print("Limits for column %d : %g,%g"%(1+i,rays[:,i].min(),rays[:,i].max()))
-    # plot_scatter(rays[:,0],rays[:,2],xrange=[-3,3],yrange=[-3,3])
-
-
-    # Gaussian
-    gs = SourceGeometrical()
-    gs.set_spatial_type_gaussian(2e-6,1e-6)
-    rays = gs.calculate_rays(1000)
-
-    for i in range(6):
-        print("Std for column %d : %g"%(i+1,rays[:,i].std()))
-
-    # Ellipse
-    gs = SourceGeometrical()
-    gs.set_spatial_type_ellipse(2,1)
-    rays = gs.calculate_rays(1000)
-    # plot_scatter(rays[:,0],rays[:,2],xrange=[-3,3],yrange=[-3,3])
-
-    # Uniform divergence
-    gs = SourceGeometrical()
-    print(">>>>",rays[:,3].shape)
-    gs.set_angular_distribution_uniform(-10e-6,5e-6,-3e-6,6e-6)
-    rays = gs.calculate_rays(5000)
-    # plot_scatter(1e6*rays[:,3],1e6*rays[:,5],xrange=[-10,10],yrange=[-10,10])
-
-    # Gaussian divergence
-    gs = SourceGeometrical()
-    print(">>>>",rays[:,3].shape)
-    gs.set_angular_distribution_gaussian(2e-5,1e-5)
-
-    rays = gs.calculate_rays(5000)
-    # plot_scatter(1e6*rays[:,3],1e6*rays[:,5],title="Gaussian div")
-
-    # Conical divergence
-    gs = SourceGeometrical()
-    print(">>>>",rays[:,3].shape)
-    gs.set_angular_distribution_conical(2e-5,1e-5)
-
-    rays = gs.calculate_rays(5000)
-    # plot_scatter(1e6*rays[:,3],1e6*rays[:,5],title="Conical div")
-
-
-    # energy monochromatic
-    gs = SourceGeometrical()
-    # gs.set_energy_distribution_singleline(2000.0,unit='eV')
-    # gs.set_energy_distribution_severallines([1000.0,2000.0,3000.,8000],unit='eV')
-    # gs.set_energy_distribution_relativeintensities([1000.0,2000.0,3000.,8000],[1.,2.,3,4],unit='eV')
-    gs.set_energy_distribution_gaussian(10000.0,2000.0,unit='eV')
-
-    rays = gs.calculate_rays(5000)
-    ev = gs._wavenumber_to_energy(rays[:,10])
-    # plot_scatter(rays[:,11],ev,title="Energy: xxx")
-
-
-    # energy external spectrum
-    gs = SourceGeometrical()
-    x = numpy.linspace(1000.0,100000,2000)
-    y = numpy.exp(- (x-50000)**2 / 2 / 10000**2 )
-    # plot(x,y)
-    gs.set_energy_distribution_userdefined(x,y,unit='eV')
-    rays = gs.calculate_rays(5000)
-    ev = gs._wavenumber_to_energy(rays[:,10])
-    plot_scatter(rays[:,11],ev,title="Energy: sampled from numerical spectrum")
-
-    print(dir(gs))
+    pass
 
